@@ -2,22 +2,12 @@ package RapidApp;
 use strict;
 use warnings;
 
-our $VERSION = 0.99017;
+our $VERSION = 0.99018;
+
+use Carp::Clan;
 
 # ABSTRACT: Turnkey ajaxy webapps
 
-# use to require some modules with specific min versions:
-use Catalyst 5.90002;
-use Plack 1.0029;
-use DBIx::Class 0.08250;
-use SQL::Translator 0.11016;
-use Template 2.25;
-use DateTime::Format::SQLite;
-use JavaScript::ExtJS::V3 '3.4.0';
-
-# quick Module version check cmd:
-#   perl -M"Catalyst 999" -e1
-
 use File::ShareDir qw(dist_dir);
 
 sub share_dir {
@@ -25,7 +15,6 @@ sub share_dir {
   return $ENV{RAPIDAPP_SHARE_DIR} || dist_dir($class);
 }
 
-
 1;
 
 
